@@ -21,17 +21,17 @@ import {
 } from "react-searchkit";
 import { Grid } from "semantic-ui-react";
 import { SearchConfigurationContext } from "./context";
+import { i18next } from "@translations/invenio_app_rdm/i18next";
 
 export const Results = ({ currentResultsState = {} }) => {
   const { total } = currentResultsState.data;
-  const { sortOptions, layoutOptions, paginationOptions } = useContext(
-    SearchConfigurationContext
-  );
+  const { sortOptions, layoutOptions, paginationOptions, buildUID } =
+    useContext(SearchConfigurationContext);
   const multipleLayouts = layoutOptions.listView && layoutOptions.gridView;
   return (
     (total || null) && (
       <Overridable
-        id={"SearchApp.results"}
+        id={buildUID("SearchApp.results")}
         {...{
           sortOptions,
           paginationOptions,
@@ -82,12 +82,13 @@ export const ResultOptions = ({ currentResultsState = {} }) => {
     paginationOptions,
     sortOrderDisabled,
     layoutOptions,
+    buildUID,
   } = useContext(SearchConfigurationContext);
   const multipleLayouts = layoutOptions.listView && layoutOptions.gridView;
   return (
     (total || null) && (
       <Overridable
-        id={"SearchApp.resultOptions"}
+        id={buildUID("SearchApp.resultOptions")}
         {...{
           currentResultsState,
           sortOptions,
@@ -103,10 +104,14 @@ export const ResultOptions = ({ currentResultsState = {} }) => {
             </Grid.Column>
             <Grid.Column width={8} textAlign="right">
               {sortOptions && (
-                <Overridable id={"SearchApp.sort"} options={sortOptions}>
+                <Overridable
+                  id={buildUID("SearchApp.sort")}
+                  options={sortOptions}
+                >
                   <Sort
                     sortOrderDisabled={sortOrderDisabled || false}
                     values={sortOptions}
+                    ariaLabel={i18next.t("Sort")}
                   />
                 </Overridable>
               )}
